commit 98c116be095e20249651d968e4e6497e021c47f0
Author: Romuald <devnull@localhost>
Date:   Sun Dec 14 15:49:44 2008 +0100

    Gestion des Coupes/Tournoi en plus des Championnat.

diff --git a/functions.php b/functions.php
index 84a0f8f..58f2f5d 100644
--- a/functions.php
+++ b/functions.php
@@ -6,7 +6,9 @@ $DIVISION = array(
 	"PN" => "Pr&eacute;-National",
 	"R" => "R&eacute;gional",
 	"PR" => "Pr&eacute;-R&eacute;gional",
-	"D" => "D&eacute;partemental"
+	"D" => "D&eacute;partemental",
+	"C" => "coupe",
+	"T" => "tournoi"
 );
 
 $SEP_DIV = "_";
diff --git a/admin/admin.php b/admin/admin.php
index 19f6b54..1f5bcb8 100644
--- a/admin/admin.php
+++ b/admin/admin.php
@@ -1,6 +1,6 @@
 <?php
 /*
  * admin.php - Administration du championnat
  * Copyright (C) 2008 Romuald DELAVERGNE  <delavergne@free.fr>
  *
  * This source code is licensed under the GNU General Public License,
@@ -16,6 +16,7 @@
 		require_once 'functions.php';
 
 	function hiddenVars() { ?>
+			<input type="hidden" name="typeCompetition" value="<?=$_POST['typeCompetition']?>" />
 			<input type="hidden" name="saison" value="<?=$_POST['saison']?>" />
 			<input type="hidden" name="div1" value="<?=$_POST['div1']?>" />
 			<input type="hidden" name="div2" value="<?=$_POST['div2']?>" />
@@ -39,7 +40,6 @@
 
 	// Données reçues par l'index ou cette page
 	$championnat = $_POST['championnat'];
-	if ($championnat == "ajouter un championnat") $championnat = "ajouter";
 	if ($_POST['validation_championnat'] == "ajouter") $championnat = "validation_ajouter";
 	if ($_POST['validation_championnat'] == "modifier") $championnat = "validation_modifier";
 	if ($_POST['validation_penalites'] == "valider") $championnat = "validation_penalites";
@@ -136,14 +136,14 @@
 				if (!file_exists($path)) {
 					mkdirRecursive($path);
 					my_file_put_contents("$path/equipes", $equipes);
-					$message = "Le championnat a &eacute;t&eacute; ajout&eacute;.";
+					$message = "La comp&eacute;tition a &eacute;t&eacute; ajout&eacute;e.";
 				} else {
-					$message = "Le championnat existe d&eacute;j&agrave; !";
+					$message = "La comp&eacute;tition existe d&eacute;j&agrave; !";
 				}
 				break;
 			case "validation_modifier":
 				my_file_put_contents("$path/equipes", $equipes);
-				$message = "Le championnat a &eacute;t&eacute; mis à jour.";
+				$message = "La comp&eacute;tition a &eacute;t&eacute; mise à jour.";
 				break;
 			case "validation_penalites":
 				$vars = preg_grep("/^pen_/", array_keys($_POST));
@@ -247,6 +247,21 @@
 <?php } ?>
 				</td>
 			</tr>
+<?php if ($_POST['typeCompetition'] != "") { ?>
+			<input type="hidden" name="div1" value="<?=$_POST['typeCompetition']?>" />
+			<tr>
+				<td><?=$_POST['typeCompetition'] == "C" ? "Coupe" : "Tournoi"?></td>
+				<td>
+					:
+<?php if ($championnat == "ajouter") { ?>
+					<input type="text" name="div2" value="" />
+<?php } else { ?>
+					<input type="hidden" name="div2" value="<?=$_POST['div2']?>" />
+					<?=$_POST['div2']."\n"?>
+<?php } ?>
+				</td>
+			</tr>
+<?php } else { ?>
 			<tr>
 				<td>Division</td>
 				<td>
@@ -268,13 +283,14 @@
 <?php } ?>
 				</td>
 			</tr>
+<?php } ?>
 <?php if ($championnat == "ajouter" || $_POST['poule']) { ?>
 			<tr>
-				<td>Poule</td>
+				<td><?=($_POST['typeCompetition'] != "") ? "Poule/Tableau" : "Poule"?></td>
 				<td>
 					:
 <?php if ($championnat == "ajouter") { ?>
-					<input type="text" name="poule" size="3" value="" />
+					<input type="text" name="poule" value="" />
 <?php } else { ?>
 					<input type="hidden" name="poule" value="<?=$_POST['poule']?>" />
 					<?=$_POST['poule']."\n"?>
@@ -282,7 +298,7 @@
 				</td>
 			</tr>
 <?php } ?>
-<?php if ($championnat == "ajouter" || $_POST['phase']) { ?>
+<?php if (($championnat == "ajouter" || $_POST['phase']) && $_POST['typeCompetition'] == "") { ?>
 			<tr>
 				<td>Phase</td>
 				<td>
@@ -302,7 +318,7 @@
 <?php } ?>
 			<tr>
 				<td colspan="2">
-					Liste des &eacute;quipes :
+					Liste des <?=$_POST['typeCompetition'] == "T" ? "joueurs" : "&eacute;quipes"?> :
 				</td>
 			</tr>
 			<tr>
@@ -1,6 +1,6 @@
 <?php
 /*
- * admin.php - Administration du championnat
+ * admin.php - Administration des compétitions
  * Copyright (C) 2008 Romuald DELAVERGNE  <delavergne@free.fr>
  *
diff --git a/index.php b/index.php
index 662cec5..ac4dbd9 100644
--- a/index.php
+++ b/index.php
@@ -1,6 +1,6 @@
 <?php
 /*
  * index.php - Visualisation du championnat
  * Copyright (C) 2008 Romuald DELAVERGNE  <delavergne@free.fr>
  *
  * This source code is licensed under the GNU General Public License,
@@ -86,12 +86,15 @@
 		closedir($dir);
 	}
 
+	$titleDiv = ($div1 == "C" || $div1 == "T") ? $DIVISION[$div1] : "division";
+	$titleSubdiv = (($div1 == "C" || $div1 == "T") && $poule) ? "poule/tableau" : "poule";
+
 	// Récupération des pénalités
 	$Pen = getPenalites($path);
 ?>
 <html>
 <head>
-	<title>Championnat de tennis de table</title>
+	<title>Comp&eacute;titions de tennis de table</title>
 	<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
 	<meta http-equiv="Content-language" content="fr" />
 	<meta name="copyright" content="Tous droits réservés - All Rights Reserved" />
@@ -105,6 +108,8 @@
 	echo "<pre>\n";
 	echo "saison  =/$saison/\n";
 	echo "division=/$division/\n";
+	echo "div1    =/$div1/\n";
+	echo "div2    =/$div2/\n";
 	echo "subdiv  =/$subdiv/\n";
 	echo "poule   =/$poule/\n";
 	echo "phase   =/$phase/\n";
@@ -113,6 +118,7 @@
 	print_r($rencontres);
 	//print_r($saisons);
 	//print_r($divisions);
+	print_r($subdivs);
 	echo "</pre>\n";
 	*/
 ?>
@@ -131,20 +137,20 @@
 			</select>
 <?php } ?>
 <?php if ($divisions) { ?>
-			Division :
+			<?=$titleDiv?> :
 			<select name="division">
 <?php
 		foreach ($divisions as $d) {
 			list($a, $b) = explode($SEP_DIV, $d);
 			echo "\t\t\t\t<option value=\"$d\"";
 			if ($d == $division) echo " selected";
-			echo ">".$a.$b."</option>\n";
+			echo ">".(($a == "C" || $a == "T") ? $b : $a.$b)."</option>\n";
 		}
 ?>
 			</select>
 <?php } ?>
 <?php if ($poule) { ?>
-			Poule :
+			<?=$titleSubdiv?> :
 			<select name="poule">
 <?php
 		foreach ($subdivs as $s) {
@@ -181,12 +187,20 @@
 		<input type="hidden" name="div2" value="<?=$div2?>" />
 		<input type="hidden" name="poule" value="<?=$poule?>" />
 		<input type="hidden" name="phase" value="<?=$phase?>" />
-		<div id="championnat-ajouter">
-			<input type="submit" name="championnat" value="ajouter un championnat" />
+		<div id="boutons-global">
+			<select name="typeCompetition">
+				<option value="">championnat</option>
+				<option value="C"<?=$div1 == "C" ? " selected" : ""?>>coupe</option>
+				<option value="T"<?=$div1 == "T" ? " selected" : ""?>>tournoi</option>
+			</select>
+			<input type="submit" name="championnat" value="ajouter" />
 <?php 	if ($saisons) { ?>
+			-
 			<input type="submit" name="exporter" value="exporter" />
+			-
 			<input type="submit" name="importer" value="importer" />
 <?php if (FALSE) { ?>
+			-
 			<input type="submit" name="supprimer-tout" value="tout supprimer" />
 <?php } ?>
 <?php 	} ?>
@@ -194,7 +208,20 @@
 <?php 	if ($saisons) { ?>
 		<div id="boutons-championnat">
 			<input type="submit" name="championnat" value="modifier" />
-			<input type="submit" name="championnat" value="supprimer" onClick='return confirm("Voulez-vous vraiment effacer tout le championnat ?")' />
+<?php
+	if ($phase) {
+		$compet = "la phase";
+	} elseif ($poule) {
+		if ($div1 == "C" || $div1 == "T") {
+			$compet = "la poule ou le tableau";
+		} else {
+			$compet = "la poule";
+		}
+	} else {
+		$compet = "la division";
+	}
+?>
+			<input type="submit" name="championnat" value="supprimer" onClick='return confirm("Voulez-vous vraiment effacer <?=$compet?> ?")' />
 			<input type="submit" name="championnat" value="p&eacute;nalit&eacute;s" />
 		</div>
 <?php 	} ?>
@@ -1,6 +1,6 @@
 <?php
 /*
- * index.php - Visualisation du championnat
+ * index.php - Visualisation des compétitions
  * Copyright (C) 2008 Romuald DELAVERGNE  <delavergne@free.fr>
  *
